@@ -1,12 +1,12 @@
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 #Load the package
 require(cheese)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 #Look at the data
 heart_disease
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 div_dat <-
   heart_disease %>%
     divide(
@@ -15,29 +15,29 @@ div_dat <-
     )
 div_dat
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 div_dat %>%
   fasten()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 div_dat %>%
   fasten(
     into = c("Sex", "HeartDisease")
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 div_dat %>%
   fasten(
     into = "Sex"
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 div_dat %>%
   fasten(
     into = c("", "HeartDisease")
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   divide(
     Sex,
@@ -45,37 +45,37 @@ heart_disease %>%
     depth = 1
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 div_dat %>%
   fasten(
     into = "HeartDisease",
     depth = 1
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 div_dat %>%
   fasten(
     into = "HeartDisease",
     depth = -1
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   dish(
     f = cor,
     left = c(BP, Cholesterol),
-    right = is.numeric
+    right = where(is.numeric)
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
-  dplyr::select_if(is.numeric) %>% #Need to do this so only numeric columns are evaluated
+  dplyr::select(where(is.numeric)) %>% #Need to do this so only numeric columns are evaluated
   dish(
     f = cor,
     left = c(BP, Cholesterol)
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   dish(
     f = function(y, x) lm(y ~ ., data = x),
@@ -83,7 +83,7 @@ heart_disease %>%
     each_right = FALSE
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   stratiply(
     f = glm,
@@ -92,7 +92,7 @@ heart_disease %>%
     family = "binomial"
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   stratiply(
     f = glm,
@@ -101,14 +101,14 @@ heart_disease %>%
     family = "binomial"
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   typly(
     f = mean,
     types = c("numeric", "logical")
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   typly(
     f = table,
@@ -117,7 +117,7 @@ heart_disease %>%
     useNA = "always"
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 absorb(
   key = c("mean", "sd", "var"),
   value = c("10", "2", "4"),
@@ -129,7 +129,7 @@ absorb(
     )
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 age_stats <-
   heart_disease %>%
   dplyr::group_by(
@@ -140,9 +140,9 @@ age_stats <-
     mean = round(mean(Age), 2),
     sd = round(sd(Age), 2),
     median = median(Age),
-    iqr = IQR(Age)
+    iqr = IQR(Age),
+    .groups = "drop"
   ) %>%
-  dplyr::ungroup() %>%
   tidyr::gather(
     key = "key",
     value = "value",
@@ -151,7 +151,7 @@ age_stats <-
   )
 age_stats
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 age_stats %>%
   dplyr::group_by(
     ExerciseInducedAngina,
@@ -166,18 +166,18 @@ age_stats %>%
           c(
             "mean (sd) | median (iqr)"
           )
-      )
-  ) %>%
-  dplyr::ungroup()
+      ),
+    .groups = "drop"
+  ) 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 absorb(
   key = age_stats$key,
   value = age_stats$value,
   text = c("(mean) / (sd)", "median")
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 absorb(
   key = age_stats$key,
   value = age_stats$value,
@@ -187,7 +187,7 @@ absorb(
   trace = TRUE
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 #Make a divided data frame
 div_dat1 <-
   heart_disease %>%
@@ -206,31 +206,31 @@ div_dat1 %>%
     predicate = is.data.frame
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 div_dat1 %>%
   depths_string(
     predicate = is.data.frame,
     bare = FALSE
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 set.seed(123)
 heart_disease %>%
   muddle()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   muddle(
     at = Age
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   muddle(
     size = 5
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 mod_results <-
   heart_disease %>%
   
@@ -261,7 +261,7 @@ mod_results <-
   )
 mod_results
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 straught1 <-
   mod_results %>%
   stretch(
@@ -270,7 +270,7 @@ straught1 <-
   )
 straught1
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 straught2 <-
   mod_results %>%
   stretch(
@@ -279,30 +279,30 @@ straught2 <-
   )
 straught2
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 straught1 %>%
   grable(
     at = -c(Sex, Parameter)
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 straught2 %>%
   grable(
     at = -Parameter
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   descriptives()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   univariate_associations(
     f = list(AIC = function(y, x) AIC(lm(y ~ x))),
     responses = c(BP, Cholesterol)
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 heart_disease %>%
   univariate_table()
 
